﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using ITCWebshop4.Models;

namespace ITCWebshop4.Controllers
{
	public class UserController : Controller
	{
		private ITCDBContext db = new ITCDBContext();

		//
		// GET: /User/

		public ActionResult Index()
		{
			return View(db.Users.ToList());
		}

		//
		// GET: /User/Details/5

		public ActionResult Details(Guid id = default(Guid))
		{
			tblUser user = db.Users.Find(id);
			if (user == null)
			{
				return HttpNotFound();
			}
			return View(user);
		}

		//
		// GET: /User/Create

		public ActionResult Create()
		{
			return View();
		}

		//
		// POST: /User/Create

		[HttpPost]
		public ActionResult Create(tblUser user)
		{
			if (ModelState.IsValid)
			{
				user.UserId = Guid.NewGuid();
				
				user.CreatedAt = DateTime.Now;
				user.CreatedBy = "sa";

				db.Users.Add(user);
				db.SaveChanges();
				return RedirectToAction("Index");
			}

			return View(user);
		}

		//
		// GET: /User/Edit/5

		public ActionResult Edit(Guid id = default(Guid))
		{
			tblUser user = db.Users.Find(id);
			if (user == null)
			{
				return HttpNotFound();
			}
			return View(user);
		}

		//
		// POST: /User/Edit/5

		[HttpPost]
		public ActionResult Edit(tblUser user)
		{
			if (ModelState.IsValid)
			{
				user.ChangedAt = DateTime.Now;
				user.ChangedBy = "sa";
				db.Entry(user).State = EntityState.Modified;
				db.SaveChanges();
				return RedirectToAction("Index");
			}
			return View(user);
		}

		//
		// GET: /User/Delete/5

		public ActionResult Delete(Guid id = default(Guid))
		{
			tblUser user = db.Users.Find(id);
			if (user == null)
			{
				return HttpNotFound();
			}
			return View(user);
		}

		//
		// POST: /User/Delete/5

		[HttpPost, ActionName("Delete")]
		public ActionResult DeleteConfirmed(Guid id)
		{
			tblUser user = db.Users.Find(id);
			db.Users.Remove(user);
			db.SaveChanges();
			return RedirectToAction("Index");
		}


		public ActionResult SearchUser(string searchString)
		{
			var users = from m in db.Users
						 select m;

			if (!String.IsNullOrEmpty(searchString))
			{
				users = users.Where(s => s.UserName.Contains(searchString));
			}

			return View(users);
		}

		[HttpPost]
		public string SearchUser(FormCollection fc, string searchString)
		{
			return "<h3> From [HttpPost]SearchUser: " + searchString + "</h3>";
		}

		protected override void Dispose(bool disposing)
		{
			db.Dispose();
			base.Dispose(disposing);
		}
	}
}